:orphan:

.. _examples_gallery:

Examples
========

A gallery of examples and that showcase how TradeTide can be used. Some examples demonstrate the use of the API in general and some demonstrate specific applications in tutorial form.


.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Moving Average Crossing indicator">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_MACD_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_MACD.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Moving Average Crossing indicator</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Boilinger Band">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_BB_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_BB.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Boilinger Band</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Relative Strength Index">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_RSI_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_RSI.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Relative Strength Index</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Relative Momentum Index">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_RMI_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_RMI.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Relative Momentum Index</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Moving Average Crossing">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_SMA_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_SMA.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Moving Average Crossing</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Strategy">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_strategy_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_strategy.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Strategy</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /gallery/plot_MACD
   /gallery/plot_BB
   /gallery/plot_RSI
   /gallery/plot_RMI
   /gallery/plot_SMA
   /gallery/plot_strategy



.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
